package cn.com.poc.thirdparty.resource.demand.ai.function;

import cn.com.poc.common.service.RedisService;
import cn.com.poc.common.utils.BlContext;
import cn.com.poc.common.utils.DateUtils;
import cn.hutool.json.JSONObject;
import com.google.gson.Gson;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Service
public class SetLongMemoryFunction extends AbstractLargeModelFunction {

    @Resource
    private RedisService redisService;

    @Override
    public String doFunction(String content, String key) {
        // todo 执行保存长期记忆的操作
        // 创建 JSONObject 对象
        JSONObject jsonObject = new JSONObject(content);
        // 提取 content
        String contents = jsonObject.getStr("content");
        String contentKey = key + ":" + BlContext.getCurrentUserNotException().getUserId().toString() + ":" + "longMemory";
        Map<Object, Object> hmget = redisService.hmget(key);
        Map<String, Object> result = new HashMap<>();
        for (Map.Entry<Object, Object> entry : hmget.entrySet()) {
            if (entry.getKey() instanceof String) {
                // 将 Object 强制转换为 String
                String tempKey = (String) entry.getKey();
                result.put(tempKey, entry.getValue());
            }
        }
        List<String> list = new ArrayList<>();
        list.add("timestamp:" + DateUtils.getCurrTime());
        list.add("content:" + contents);
        result.put(Integer.toString(hmget.size()), list);
        redisService.hmset(contentKey, result);
        return "SUCCESS";
    }

    @Override
    public List<String> getLLMConfig() {
        Map<String, Object> config = new HashMap<>();
        Map<String, Object> function = new HashMap<>();

        Map<String, Object> content = new HashMap<>();
        content.put("type", "string");
        content.put("description", "内容的详细说明");

        Map<String, Object> properties = new HashMap<>();
        properties.put("content", content);

        Map<String, Object> parameters = new HashMap<>();
        parameters.put("type", "object");
        parameters.put("properties", properties);

        List<String> required = new ArrayList<>();
        required.add("content");
        parameters.put("required", required);


        function.put("name", "set_long_memory");
        function.put("description", "用来保存用户想记录的内容（什么内容都可以）");
        function.put("parameters", parameters);

        config.put("type", "function");
        config.put("function", function);

        // 将 Map 转换为 JSON 字符串
        Gson gson = new Gson();
        String jsonString = gson.toJson(config);

        List<String> resultList = new ArrayList<>();
        resultList.add(jsonString);
        return resultList;
    }

    @Override
    public List<String> getVariableStructureLLMConfig(String[] variableStructure) {
        return null;
    }
}
